@@ -25,7 +25,7 @@ pkcs11 = PyKCS11Lib()
 pkcs11.load()  # define environment variable PYKCS11LIB=YourPKCS11Lib
 
 # get 1st slot
-slot = pkcs11.getSlotList()[0]
+slot = pkcs11.getSlotList(tokenPresent=True)[0]
 
 session = pkcs11.openSession(slot, CKF_SERIAL_SESSION | CKF_RW_SESSION)
 session.login("1234")
@@ -36,7 +36,7 @@ keyID = (0x22,)
 # find public key and print modulus
 pubKey = session.findObjects([(CKA_CLASS, CKO_PUBLIC_KEY), (CKA_ID, keyID)])[0]
 modulus = session.getAttributeValue(pubKey, [CKA_MODULUS])[0]
-print("\nmodulus: " + binascii.hexlify(bytearray(modulus)))
+print("\nmodulus: {}".format(binascii.hexlify(bytearray(modulus))))
 
 # logout
 session.logout()
