@@ -19,6 +19,10 @@ class TestUtil(unittest.TestCase):
     def test_CKR(self):
         self.assertEqual(PyKCS11.CKR_VENDOR_DEFINED, 0x80000000)
 
+    def test_CKH(self):
+        self.assertEqual(PyKCS11.CKH_USER_INTERFACE, 3)
+        self.assertEqual(PyKCS11.CKH['CKH_USER_INTERFACE'], 3)
+
 
 if __name__ == "__main__":
     unittest.main()
